==> coq-7.0.tar.gz: coq-7.0/pretyping/cases.mli <==
(***********************************************************************)
(*  v      *   The Coq Proof Assistant  /  The Coq Development Team    *)
(* <O___,, *        INRIA-Rocquencourt  &  LRI-CNRS-Orsay              *)
(*   \VV/  *************************************************************)
(*    //   *      This file is distributed under the terms of the      *)
(*         *       GNU Lesser General Public License Version 2.1       *)
(***********************************************************************)

(*i $Id: cases.mli,v 1.13 2001/04/13 23:52:25 herbelin Exp $ i*)

(*i*)
open Names
open Term
open Evd
open Environ
open Inductive
open Rawterm
open Evarutil
(*i*)

type pattern_matching_error =
  | BadPattern of constructor * constr
  | BadConstructor of constructor * inductive
  | WrongNumargConstructor of constructor_path * int
  | WrongPredicateArity of constr * constr * constr
  | NeedsInversion of constr * constr
  | UnusedClause of cases_pattern list
  | NonExhaustive of cases_pattern list

exception PatternMatchingError of env * pattern_matching_error

(* Used for old cases in pretyping *)

val branch_scheme : 
  env -> 'a evar_defs -> bool -> inductive_family -> constr array

val pred_case_ml_onebranch : loc -> env -> 'c evar_map -> bool ->
  inductive_type -> int * constr * constr -> constr 

(* Compilation of pattern-matching. *)

val compile_cases :
  loc -> (type_constraint -> env -> rawconstr -> unsafe_judgment)
  * 'a evar_defs -> type_constraint -> env ->
    rawconstr option * rawconstr list *
    (loc * identifier list * cases_pattern list * rawconstr) list ->
    unsafe_judgment

==> coq_7.2.orig.tar.gz: coq-7.2.orig/pretyping/cases.mli <==
(***********************************************************************)
(*  v      *   The Coq Proof Assistant  /  The Coq Development Team    *)
(* <O___,, *        INRIA-Rocquencourt  &  LRI-CNRS-Orsay              *)
(*   \VV/  *************************************************************)
(*    //   *      This file is distributed under the terms of the      *)
(*         *       GNU Lesser General Public License Version 2.1       *)
(***********************************************************************)

(*i $Id: cases.mli,v 1.19 2001/12/18 09:16:00 herbelin Exp $ i*)

(*i*)
open Names
open Term
open Evd
open Environ
open Inductiveops
open Rawterm
open Evarutil
(*i*)

type pattern_matching_error =
  | BadPattern of constructor * constr
  | BadConstructor of constructor * inductive
  | WrongNumargConstructor of constructor * int
  | WrongPredicateArity of constr * constr * constr
  | NeedsInversion of constr * constr
  | UnusedClause of cases_pattern list
  | NonExhaustive of cases_pattern list
  | CannotInferPredicate of (constr * types) array

exception PatternMatchingError of env * pattern_matching_error

(*s Used for old cases in pretyping *)

val branch_scheme : 
  env -> evar_defs -> bool -> inductive * constr list -> constr array

type ml_case_error =
  | MlCaseAbsurd
  | MlCaseDependent

exception NotInferable of ml_case_error

val pred_case_ml : (* raises [NotInferable] if not inferable *)
  env -> evar_map -> bool -> inductive_type -> int * types -> constr 

(*s Compilation of pattern-matching. *)

val compile_cases :
  loc -> (type_constraint -> env -> rawconstr -> unsafe_judgment)
  * evar_defs -> type_constraint -> env ->
    rawconstr option * rawconstr list *
    (loc * identifier list * cases_pattern list * rawconstr) list ->
    unsafe_judgment
